who actually gives a shit about this
like dude, i just made this in order to get 100% on my first module
it's not like I actually give a shit the content of my package
come on, just look at the code and you'll realise how much I don't care about this



can this deserve an outstanding project btw? :)